@@ -1,4 +1,4 @@
-import aiohttp, json, asyncio, socket, struct
+import aiohttp, json, asyncio, ssl, socket, struct
 from bson import encode
 from .channel import Channel
 from .message import Message
@@ -19,6 +19,56 @@ class HTTP:
         self.__processingSize = 0
         self.loop = asyncio.get_event_loop()
         return 
+    def __get_booking_data(self):
+        hostname = "booking-loco.kakao.com"
+        context = ssl.create_default_context()
+
+        with socket.create_connection((hostname, 443)) as sock:
+            with context.wrap_socket(sock, server_hostname=hostname) as ssock:
+                data = encode({"os": "win32", "model": "", "MCCMNC": ""})
+
+                b = Packet(1000, 0, "GETCONF", 0, data)
+                ssock.write(b.toLocoPacket())
+
+                data = ssock.recv(4096)
+
+                recvPacket = Packet()
+                recvPacket.readLocoPacket(data)
+                return recvPacket
+
+    def __get_checkin_data(self, host: str, port: int):
+        crypto = CryptoManager()
+        sock = socket.socket()
+        sock.connect((host, port))
+
+        handshakePacket = crypto.getHandshakePacket()
+        sock.send(handshakePacket)
+
+        p = Packet(
+            1,
+            0,
+            "CHECKIN",
+            0,
+            encode(
+                {
+                    "userId": 0,
+                    "os": 'win32',
+                    "ntype": 0,
+                    "appVer": '3.2.6',
+                    "MCCMNC": "999",
+                    "lang": "ko",
+                }
+            ),
+        )
+
+        sock.send(p.toEncryptedLocoPacket(crypto))
+
+        data = sock.recv(2048)
+
+        recvPacket = Packet()
+        recvPacket.readEncryptedLocoPacket(data, crypto)
+
+        return recvPacket
     async def try_passcode(self, email, password, passcode):
         headers = {}
         headers["User-Agent"] = "KT/3.2.6 Wd/10.0 ko"
@@ -214,13 +264,13 @@ class HTTP:
                     currentPacketSize = 0
 
     async def get_address(self, host, port):
-        checkinObj = getCheckInData(host, port).toJsonBody()
+        checkinObj = self.__get_checkin_data(host, port).toJsonBody()
         port = checkinObj["port"]
         address = checkinObj["host"]
         return address, port
     async def get_ticket_address(self):
         
-        bookingObj = getBookingData().toJsonBody()
+        bookingObj = self.__get_booking_data().toJsonBody()
         port = bookingObj["wifi"]["ports"][0]
         address = bookingObj["ticket"]["lsl"][0]
         return address, port
